convert_to_real_native_path

Function convert_to_real_native_path 

pub fn convert_to_real_native_path(
    path: impl AsRef<Path>,
    paths_list: &[(PathBuf, PathBuf)],
) -> PathBuf
Convert the provided virtual guest path to a real host path, returning a PathBuf instead of a RealPath. If the guest path does not match any of the provided virtual paths, it will return the original path.