convert_to_real_path

Function convert_to_real_path 

pub fn convert_to_real_path(
    path: impl AsRef<Path>,
    paths_list: &[(PathBuf, PathBuf)],
) -> Option<RealPath>
Convert the provided virtual guest path to a real host path. If the guest path does not match any of the provided virtual paths, it will return None.