pub struct DownloadPrebuiltOutput {
pub archive_prefix: Option<String>,
pub checksum: Option<Checksum>,
pub checksum_name: Option<String>,
pub checksum_public_key: Option<String>,
pub checksum_url: Option<String>,
pub download_name: Option<String>,
pub download_url: String,
pub http_headers: HashMap<String, String, FxBuildHasher>,
pub post_script: Option<PathBuf>,
}Expand description
Output returned by the download_prebuilt function.
Fields
archive_prefix: Option<String>Name of the direct folder within the archive that contains the tool, and will be removed when unpacking the archive.
checksum: Option<Checksum>The checksum hash itself.
checksum_name: Option<String>File name of the checksum to download. If not provided, will attempt to extract it from the URL.
checksum_public_key: Option<String>Public key to use for checksum verification.
checksum_url: Option<String>A secure URL to download the checksum file for verification. If the tool does not support checksum verification, this setting can be omitted.
download_name: Option<String>File name of the archive to download. If not provided, will attempt to extract it from the URL.
download_url: StringA secure URL to download the tool/archive.
http_headers: HashMap<String, String, FxBuildHasher>A map of HTTP headers to include in all requests during the download phase.
post_script: Option<PathBuf>A script, relative from the install directory, to execute after the prebuilt has been installed.