pub struct ExtendTaskCommandInput {
pub args: Vec<String>,
pub context: MoonContext,
pub command: String,
pub extension_config: Value,
pub globals_dir: Option<VirtualPath>,
pub project: ProjectFragment,
pub task: TaskFragment,
pub toolchain_config: Value,
}Expand description
Input passed to the extend_task_command function.
Fields
args: Vec<String>The current arguments, after the command.
context: MoonContextCurrent moon context.
command: StringThe current command (binary/program).
extension_config: ValueWorkspace extension configuration. Is null when within toolchains.
globals_dir: Option<VirtualPath>Virtual path to a global executables directory for the current toolchain. Is null when within extensions.
project: ProjectFragmentFragment of the project that the task belongs to.
task: TaskFragmentFragment of the owning task.
toolchain_config: ValueWorkspace and project merged toolchain configuration, with the latter taking precedence. Is null when within extensions.