pub struct InitializePluginOutput {
pub config_url: Option<String>,
pub default_settings: FxHashMap<String, Value>,
pub docs_url: Option<String>,
pub prompts: Vec<SettingPrompt>,
}Expand description
Output returned from the initialize functions.
Fields
config_url: Option<String>A URL to documentation about available configuration settings.
default_settings: FxHashMap<String, Value>Settings to include in the injected toolchain config file. Supports dot notation for the keys.
docs_url: Option<String>A URL to documentation about the toolchain.
prompts: Vec<SettingPrompt>A list of questions to prompt the user about configuration settings and the values to inject.