pub struct SetupToolchainOutput {
pub changed_files: Vec<VirtualPath>,
pub operations: Vec<Operation>,
pub installed: bool,
}Expand description
Output returned from the setup_toolchain function.
Fields
changed_files: Vec<VirtualPath>List of virtual paths that have been changed because of this action.
operations: Vec<Operation>Operations that were performed. This can be used to track metadata like time taken, result status, and more.
installed: boolWhether the tool was installed or not. This field is ignored if set, and is defined on the host side.